@@ -1,8 +1,7 @@
-/*  $Id: PixmapArray.h,v 1.5 2012/07/08 02:57:14 sarrazip Exp $
-    PixmapArray.h - Object containing an array of Pixmaps.
+/*  PixmapArray.h - Object containing an array of Pixmaps.
 
     flatzebra - Generic 2D Game Engine library
-    Copyright (C) 1999-2012 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 1999-2024 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,6 +27,7 @@
 #include <SDL.h>
 #include <SDL_image.h>
 
+#include <assert.h>
 #include <vector>
 
 
@@ -60,12 +60,12 @@ public:
         arrays given to the constructor of this object.
         'i' must be lower than the value returned by getNumImages().
     */
-    SDL_Surface *getImage(size_t i) const;
+    SDL_Texture *getImage(size_t i) const;
     size_t getNumImages() const;
 
     /*  'image' must not be null.
     */
-    void setArrayElement(size_t i, SDL_Surface *image);
+    void setArrayElement(size_t i, SDL_Texture *image);
 
     /*  Sets or gets the size in pixels of the images in the pixmap array.
         All images in the array are assumed to be of the same size.
@@ -76,7 +76,7 @@ public:
 
 private:
 
-    std::vector<SDL_Surface *> images;
+    std::vector<SDL_Texture *> images;
     Couple imageSize;  // size in pixels of the images; all assumed same size
 
 
@@ -91,12 +91,26 @@ private:
 /*  INLINE METHODS
 */
 
-inline SDL_Surface *
-PixmapArray::getImage(size_t i) const { return images[i]; }
+inline SDL_Texture *
+PixmapArray::getImage(size_t i) const
+{
+    assert(i < images.size());
+    return images[i];
+}
+
+
 inline size_t
-PixmapArray::getNumImages() const { return images.size(); }
+PixmapArray::getNumImages() const
+{
+    return images.size();
+}
+
+
 inline Couple
-PixmapArray::getImageSize() const { return imageSize; }
+PixmapArray::getImageSize() const
+{
+    return imageSize;
+}
 
 
 }  // namespace flatzebra
