@@ -1,4 +1,4 @@
-/*  $Id: RCouple.h,v 1.7 2012/07/14 03:44:21 sarrazip Exp $
+/*  RCouple.h
     RCouple.h - Class representing a couple of integers.
 
     flatzebra - Generic 2D Game Engine library
@@ -27,6 +27,7 @@
 
 #include <assert.h>
 #include <math.h>
+#include <iostream>
 
 
 namespace flatzebra {
@@ -445,6 +446,12 @@ inline bool RCouple::safeGreaterOrEqual(double a, double b)
 }
 
 
+inline std::ostream &operator << (std::ostream &out, const RCouple &c)
+{
+    return out << '(' << c.x << ", " << c.y << ')';
+}
+
+
 }  // namespace flatzebra
 
 
