@@ -1,8 +1,7 @@
-/*  $Id: RSprite.h,v 1.2 2010/04/25 01:15:57 sarrazip Exp $
-    RSprite.h - Sprite with floating point coordinates in a 2D game.
+/*  RSprite.h - Sprite with floating point coordinates in a 2D game.
 
     flatzebra - Generic 2D Game Engine library
-    Copyright (C) 1999-2003 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 1999-2024 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -16,8 +15,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #ifndef _H_RSprite
@@ -66,7 +65,7 @@ public:
     /*  Returns the number of pixmaps in this sprite.
     */
 
-    SDL_Surface *getPixmap(size_t i) const;
+    SDL_Texture *getPixmap(size_t i) const;
     /*  Returns the pixmap at index 'i' is this sprite's pixmap list.
         This index is zero-based.
         No check is made to ensure that i is valid.
@@ -88,7 +87,16 @@ public:
     */
 
     RCouple getCenterPos() const;
-    /*        Returns the position of the center of this sprite.
+    /*  Returns the position of the center of this sprite.
+    */
+
+    void setCenterPos(const RCouple &c);
+    /*  Sets the (top-left) position so that 'c' becomes the center position.
+    */
+
+    RCouple getLowerLeftPos() const;
+    /*  Returns the position of the lower left corner of the rectangle
+        that contains the sprite.
     */
 
     RCouple getLowerRightPos() const;
@@ -139,7 +147,7 @@ public:
         'currentPixmapIndex' is initially zero.
     */
 
-    
+
     long *values;  // array
     size_t numUserValues;
 
@@ -244,6 +252,22 @@ RSprite::getCenterPos() const
     return pos + size / 2;
 }
 
+inline
+void
+RSprite::setCenterPos(const RCouple &c)
+{
+    pos = c - size / 2;
+}
+
+
+inline
+RCouple
+RSprite::getLowerLeftPos() const
+{
+    return RCouple(pos.x, pos.y + size.y);
+}
+
+
 inline
 RCouple
 RSprite::getLowerRightPos() const
@@ -346,7 +370,9 @@ inline
 unsigned long
 RSprite::decTimeToLive()
 {
-    if (timeToLive != 0) timeToLive--; return timeToLive;
+    if (timeToLive != 0)
+        --timeToLive;
+    return timeToLive;
 }
 
 inline
@@ -364,7 +390,7 @@ RSprite::getNumPixmaps() const
 }
 
 inline
-SDL_Surface *
+SDL_Texture *
 RSprite::getPixmap(size_t i) const
 {
     return thePixmapArray->getImage(i);
