@@ -1,8 +1,7 @@
-/*  $Id: Sprite.h,v 1.8 2016/04/30 14:33:27 sarrazip Exp $
-    Sprite.h - Sprite in a 2D game.
+/*  Sprite.h - Sprite in a 2D game.
 
     flatzebra - Generic 2D Game Engine library
-    Copyright (C) 1999, 2000, 2001 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 1999-2024 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -65,7 +64,7 @@ public:
     /*  Returns the number of pixmaps in this sprite.
     */
 
-    SDL_Surface *getPixmap(size_t i) const;
+    SDL_Texture *getPixmap(size_t i) const;
     /*  Returns the pixmap at index 'i' is this sprite's pixmap list.
         This index is zero-based.
         No check is made to ensure that i is valid.
@@ -397,7 +396,7 @@ Sprite::getNumPixmaps() const
 }
 
 inline
-SDL_Surface *
+SDL_Texture *
 Sprite::getPixmap(size_t i) const
 {
     return thePixmapArray->getImage(i);
